@@ -93,20 +93,30 @@ def reencode(
     path_out: str,
     fps: Optional[Union[int, float, str]] = None,
     sar: Optional[str] = None,
+    resolution: Optional[str] = None,
     debug: bool = False
 ) -> bool:
+    ''' resolution and sar should be given in the following format: "x:y"
+        fps should be lower than the original value so frames don't freeze
+    '''
+
     cmd = 'ffmpeg -y -i {}'.format(path_in)
 
     if fps or sar:
         cmd_filter = ''
 
         if fps:
-            cmd_filter += 'fps=fps={}'.format(fps)
+            cmd_filter += 'fps={}'.format(fps)
+        if resolution:
+            if len(cmd_filter) > 0:
+                cmd_filter += ','
+
+            cmd_filter += 'scale={}'.format(resolution)
         if sar:
             if len(cmd_filter) > 0:
                 cmd_filter += ','
 
-            cmd_filter += 'setsar={}'.format(sar) 
+            cmd_filter += 'setsar={}'.format(sar)
 
         cmd += ' -filter:v ' + cmd_filter
 
@@ -141,15 +151,6 @@ def flip_video_vertical(
 
     return path.exists(path_out)
 
-def flip_video_horizontal(
-    path_in: str,
-    path_out: str,
-    debug: bool = False
-) -> bool:
-    sh.sh('ffmpeg -y -i {} -vf hflip -c:a copy {}'.format(path_in, path_out), debug=debug)
-
-    return path.exists(path_out)
-
 def rotate_video(
     path_in: str,
     path_out: str,
@@ -376,12 +377,12 @@ def convert_video_to_16_9(
 
     if h is None or w is None:
         return False
-    
+
     if h == 1080 and w == 1920:
         sh.cp(in_path, out_path)
 
         return True
-    
+
     if w/h < 16/9:
         sh.sh(
             'ffmpeg -y -i ' + sh.path(in_path) + " -vf 'split[original][copy];[copy]scale=1920:-1,setsar=1:1,crop=h=1080,gblur=sigma=75[blurred];[original]scale=-1:1080[original_resized];[blurred][original_resized]overlay=(main_w-overlay_w)/2:(main_h-overlay_h)/2' " + sh.path(out_path), debug=debug
@@ -445,12 +446,12 @@ def concat_videos_reencode(
 
     for path_ in in_paths:
         cmd += ' -i ' + sh.path(path_)
-    
+
     cmd += ' -filter_complex "'
 
     for i in range(len(in_paths)):
         cmd += '[{}:v] [{}:a] '.format(i, i)
-    
+
     cmd += 'concat=n={}:v=1:a=1 [v] [a]" -map "[v]" -map "[a]" '.format(len(in_paths)) + sh.path(out_path)
 
     sh.sh(cmd, debug=debug)
